IHandshakeIP class abstract interface

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLocalIPv4() → PeerInfo?
getLocalIPv6() → PeerInfo?
getPublicIPv4() → PeerInfo?
getPublicIPv6() → PeerInfo?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited