IShspInstance class abstract interface

Interface for SHSP Instance Extends IShspPeer with handshake and connection state management

Implemented types

Properties

closing bool
Check if the instance is in closing state
no setter
handshake bool
Check if handshake has been completed
no setter
hashCode int
The hash code for this object.
no setterinherited
keepAliveSeconds int
Get the keep-alive interval in seconds
getter/setter pair
messageCallback → MessageCallback
no setterinherited
onClose CallbackOn
no setter
onClosing CallbackOn
no setter
onHandshake CallbackOn
no setter
onOpen CallbackOn
no setter
open bool
Check if the connection is open
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Close the peer connection
inherited
keepAlive() → void
Send a keep-alive message
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMessage(List<int> msg, PeerInfo info) → void
Internal callback triggered when a message arrives for this peer
inherited
sendClosed() → void
Send a closed signal
sendClosing() → void
Send a closing signal
sendHandshake() → void
Send a handshake message
sendMessage(List<int> message) → void
Send a message to this peer
inherited
serializedObject() String
Get a serialized representation of the peer
inherited
startKeepAlive() → void
Start sending keep-alive messages periodically
stopKeepAlive() → void
Stop sending keep-alive messages
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited