ShspProtocolException class
Exception thrown when a protocol-level error occurs
- Implemented types
Constructors
-
ShspProtocolException(String message, {String? messageType, Map<
String, dynamic> ? context})
Properties
-
context
→ Map<
String, dynamic> ? -
Additional context about the error
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable error message
final
- messageType → String?
-
The message type that caused the error, if applicable
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited